@@ -1,4 +1,4 @@
-﻿define(['jQuery', 'datetime', 'paper-icon-button-light'], function ($, datetime) {
+﻿define(['jQuery', 'scripts/taskbutton', 'datetime', 'paper-icon-button-light'], function ($, taskButton, datetime) {
 
     var query = {
 
@@ -192,8 +192,8 @@
 
             if (item.Status != 'Success') {
 
-                html += '<button type="button" is="paper-icon-button-light" data-resultid="' + item.Id + '" class="btnProcessResult organizerButton" title="' + Globalize.translate('ButtonOrganizeFile') + '"><iron-icon icon="folder"></iron-icon></button>';
-                html += '<button type="button" is="paper-icon-button-light" data-resultid="' + item.Id + '" class="btnDeleteResult organizerButton" title="' + Globalize.translate('ButtonDeleteFile') + '"><iron-icon icon="delete"></iron-icon></button>';
+                html += '<button type="button" is="paper-icon-button-light" data-resultid="' + item.Id + '" class="btnProcessResult organizerButton autoSize" title="' + Globalize.translate('ButtonOrganizeFile') + '"><i class="md-icon">folder</i></button>';
+                html += '<button type="button" is="paper-icon-button-light" data-resultid="' + item.Id + '" class="btnDeleteResult organizerButton autoSize" title="' + Globalize.translate('ButtonDeleteFile') + '"><i class="md-icon">delete</i></button>';
             }
 
             html += '</td>';
@@ -309,11 +309,12 @@
         reloadItems(page);
 
         // on here
-        $('.btnOrganize', page).taskButton({
+        taskButton({
             mode: 'on',
             progressElem: page.querySelector('.organizeProgress'),
             panel: page.querySelector('.organizeTaskPanel'),
-            taskKey: 'AutoOrganize'
+            taskKey: 'AutoOrganize',
+            button: page.querySelector('.btnOrganize')
         });
 
         Events.on(ApiClient, 'websocketmessage', onWebSocketMessage);
@@ -325,8 +326,9 @@
         currentResult = null;
 
         // off here
-        $('.btnOrganize', page).taskButton({
-            mode: 'off'
+        taskButton({
+            mode: 'off',
+            button: page.querySelector('.btnOrganize')
         });
 
         Events.off(ApiClient, 'websocketmessage', onWebSocketMessage);
