@@ -154,146 +154,15 @@ var Dashboard = {
 
         if (info.HasPendingRestart) {
 
-            Dashboard.hideDashboardVersionWarning();
-
-            Dashboard.getCurrentUser().then(function (currentUser) {
-
-                if (currentUser.Policy.IsAdministrator) {
-                    Dashboard.showServerRestartWarning(info);
-                }
-            });
-
         } else {
 
-            Dashboard.hideServerRestartWarning();
+            if (Dashboard.initialServerVersion != info.Version && !AppInfo.isNativeApp) {
 
-            if (Dashboard.initialServerVersion != info.Version) {
-
-                Dashboard.showDashboardRefreshNotification();
+                window.location.reload(true);
             }
         }
     },
 
-    showServerRestartWarning: function (systemInfo) {
-
-        if (AppInfo.isNativeApp) {
-            return;
-        }
-
-        var html = '<span style="margin-right: 1em;">' + Globalize.translate('MessagePleaseRestart') + '</span>';
-
-        if (systemInfo.CanSelfRestart) {
-            html += '<button is="emby-button" type="button" class="raised submit mini" onclick="this.disabled=\'disabled\';Dashboard.restartServer();"><i class="md-icon">refresh</i><span>' + Globalize.translate('ButtonRestart') + '</span></button>';
-        }
-
-        Dashboard.showFooterNotification({ id: "serverRestartWarning", html: html, forceShow: true, allowHide: false });
-    },
-
-    hideServerRestartWarning: function () {
-
-        var elem = document.getElementById('serverRestartWarning');
-        if (elem) {
-            elem.parentNode.removeChild(elem);
-        }
-    },
-
-    showDashboardRefreshNotification: function () {
-
-        if (AppInfo.isNativeApp) {
-            return;
-        }
-
-        var html = '<span style="margin-right: 1em;">' + Globalize.translate('MessagePleaseRefreshPage') + '</span>';
-
-        html += '<button is="emby-button" type="button" class="raised submit mini" onclick="this.disabled=\'disabled\';Dashboard.reloadPage();"><i class="md-icon">refresh</i><span>' + Globalize.translate('ButtonRefresh') + '</span></button>';
-
-        Dashboard.showFooterNotification({ id: "dashboardVersionWarning", html: html, forceShow: true, allowHide: false });
-    },
-
-    reloadPage: function () {
-
-        window.location.reload(true);
-    },
-
-    hideDashboardVersionWarning: function () {
-
-        var elem = document.getElementById('dashboardVersionWarning');
-
-        if (elem) {
-
-            elem.parentNode.removeChild(elem);
-        }
-    },
-
-    showFooterNotification: function (options) {
-
-        var removeOnHide = !options.id;
-
-        options.id = options.id || "notification" + new Date().getTime() + parseInt(Math.random());
-
-        if (!document.querySelector(".footer")) {
-
-            var footerHtml = '<div id="footer" class="footer" data-theme="b" class="ui-bar-b">';
-
-            footerHtml += '<div id="footerNotifications"></div>';
-            footerHtml += '</div>';
-
-            document.body.insertAdjacentHTML('beforeend', footerHtml);
-        }
-
-        var footer = document.querySelector('.footer');
-        footer.style.top = 'initial';
-        footer.classList.remove('hide');
-
-        var parentElem = footer.querySelector('#footerNotifications');
-
-        var notificationElementId = 'notification' + options.id;
-
-        var elem = parentElem.querySelector('#' + notificationElementId);
-
-        if (!elem) {
-            parentElem.insertAdjacentHTML('beforeend', '<p id="' + notificationElementId + '" class="footerNotification"></p>');
-            elem = parentElem.querySelector('#' + notificationElementId);
-        }
-
-        var onclick = removeOnHide ? "jQuery('#" + notificationElementId + "').trigger('notification.remove').remove();" : "jQuery('#" + notificationElementId + "').trigger('notification.hide').hide();";
-
-        if (options.allowHide !== false) {
-            options.html += '<span style="margin-left: 1em;"><button is="emby-button" type="button" class="submit" onclick="' + onclick + '">' + Globalize.translate('ButtonHide') + "</button></span>";
-        }
-
-        if (options.forceShow) {
-            elem.classList.remove('hide');
-        }
-
-        elem.innerHTML = options.html;
-
-        if (options.timeout) {
-
-            setTimeout(function () {
-
-                if (removeOnHide) {
-                    $(elem).trigger("notification.remove").remove();
-                } else {
-                    $(elem).trigger("notification.hide").hide();
-                }
-
-            }, options.timeout);
-        }
-
-        $(footer).on("notification.remove notification.hide", function (e) {
-
-            setTimeout(function () { // give the DOM time to catch up
-
-                if (!parentElem.innerHTML) {
-                    footer.classList.add('hide');
-                }
-
-            }, 50);
-
-        });
-    },
-
     getConfigurationPageUrl: function (name) {
         return "configurationpage?name=" + encodeURIComponent(name);
     },
@@ -400,20 +269,6 @@ var Dashboard = {
         });
     },
 
-    refreshSystemInfoFromServer: function () {
-
-        var apiClient = ApiClient;
-
-        if (apiClient && apiClient.accessToken()) {
-            if (AppInfo.enableFooterNotifications) {
-                apiClient.getSystemInfo().then(function (info) {
-
-                    Dashboard.updateSystemInfo(info);
-                });
-            }
-        }
-    },
-
     restartServer: function () {
 
         var apiClient = window.ApiClient;
@@ -449,7 +304,7 @@ var Dashboard = {
 
             // If this is back to false, the restart completed
             if (!info.HasPendingRestart) {
-                Dashboard.reloadPage();
+                window.location.reload(true);
             } else {
                 Dashboard.retryReload(retryCount);
             }
@@ -704,7 +559,7 @@ var Dashboard = {
             pageIds: ['scheduledTasksPage', 'scheduledTaskPage'],
             icon: 'schedule'
         }, {
-            name: Globalize.translate('ButtonMetadataManager'),
+            name: Globalize.translate('MetadataManager'),
             href: "edititemmetadata.html",
             pageIds: [],
             icon: 'mode_edit'
@@ -728,13 +583,7 @@ var Dashboard = {
 
         var msg = data;
 
-        if (msg.MessageType === "ServerShuttingDown") {
-            Dashboard.hideServerRestartWarning();
-        }
-        else if (msg.MessageType === "ServerRestarting") {
-            Dashboard.hideServerRestartWarning();
-        }
-        else if (msg.MessageType === "SystemInfo") {
+        if (msg.MessageType === "SystemInfo") {
             Dashboard.updateSystemInfo(msg.Data);
         }
         else if (msg.MessageType === "RestartRequired") {
@@ -1129,7 +978,7 @@ var AppInfo = {};
         }
 
         // This doesn't perform well on iOS
-        AppInfo.enableHeadRoom = !isIOS;
+        AppInfo.enableHeadRoom = !isIOS && !browserInfo.msie;
 
         // This currently isn't working on android, unfortunately
         AppInfo.supportsFileInput = !(AppInfo.isNativeApp && isAndroid);
@@ -1325,6 +1174,42 @@ var AppInfo = {};
         return layoutManager;
     }
 
+    function getAppStorage(basePath) {
+
+        try {
+            localStorage.setItem('_test', '0');
+            localStorage.removeItem('_test');
+            return basePath + "/appstorage-localstorage";
+        } catch (e) {
+            return basePath + "/appstorage-memory";
+        }
+    }
+
+    function createWindowHeadroom() {
+        // construct an instance of Headroom, passing the element
+        var headroom = new Headroom([], {
+            // or scroll tolerance per direction
+            tolerance: {
+                down: 20,
+                up: 0
+            },
+            classes: {
+                //pinned: 'appfooter--pinned',
+                //unpinned: 'appfooter--unpinned',
+                //initial: 'appfooter-headroom'
+            }
+        });
+        // initialise
+        headroom.init();
+        return headroom;
+    }
+
+    function createMainContentHammer(Hammer) {
+        
+        var hammer = new Hammer(document.querySelector('.mainDrawerPanelContent'), null);
+        return hammer;
+    }
+
     function initRequire() {
 
         var urlArgs = "v=" + (window.dashboardVersion || new Date().getDate());
@@ -1400,6 +1285,9 @@ var AppInfo = {};
 
         define("libjass", [bowerPath + "/libjass/libjass.min", "css!" + bowerPath + "/libjass/libjass"], returnFirstDependency);
 
+        define("syncJobList", ["components/syncjoblist/syncjoblist"], returnFirstDependency);
+        define("appfooter", ["components/appfooter/appfooter"], returnFirstDependency);
+        define("dockedtabs", ["components/dockedtabs/dockedtabs"], returnFirstDependency);
         define("directorybrowser", ["components/directorybrowser/directorybrowser"], returnFirstDependency);
         define("metadataEditor", [embyWebComponentsBowerPath + "/metadataeditor/metadataeditor"], returnFirstDependency);
         define("personEditor", [embyWebComponentsBowerPath + "/metadataeditor/personeditor"], returnFirstDependency);
@@ -1407,6 +1295,7 @@ var AppInfo = {};
         define("emby-collapse", [embyWebComponentsBowerPath + "/emby-collapse/emby-collapse"], returnFirstDependency);
         define("emby-button", [embyWebComponentsBowerPath + "/emby-button/emby-button"], returnFirstDependency);
         define("emby-itemscontainer", [embyWebComponentsBowerPath + "/emby-itemscontainer/emby-itemscontainer"], returnFirstDependency);
+        define("emby-tabs", [embyWebComponentsBowerPath + "/emby-tabs/emby-tabs"], returnFirstDependency);
         define("itemHoverMenu", [embyWebComponentsBowerPath + "/itemhovermenu/itemhovermenu"], returnFirstDependency);
         define("multiSelect", [embyWebComponentsBowerPath + "/multiselect/multiselect"], returnFirstDependency);
         define("alphaPicker", [embyWebComponentsBowerPath + "/alphapicker/alphapicker"], returnFirstDependency);
@@ -1433,6 +1322,7 @@ var AppInfo = {};
         define("backdrop", [embyWebComponentsBowerPath + "/backdrop/backdrop"], returnFirstDependency);
         define("fetchHelper", [embyWebComponentsBowerPath + "/fetchhelper"], returnFirstDependency);
 
+        define("roundCardStyle", ["cardStyle", 'css!' + embyWebComponentsBowerPath + "/cardbuilder/roundcard"], returnFirstDependency);
         define("cardStyle", ['css!' + embyWebComponentsBowerPath + "/cardbuilder/card"], returnFirstDependency);
         define("cardBuilder", [embyWebComponentsBowerPath + "/cardbuilder/cardbuilder"], returnFirstDependency);
         define("peoplecardbuilder", [embyWebComponentsBowerPath + "/cardbuilder/peoplecardbuilder"], returnFirstDependency);
@@ -1468,7 +1358,7 @@ var AppInfo = {};
         if (Dashboard.isRunningInCordova() && window.MainActivity) {
             paths.appStorage = "cordova/android/appstorage";
         } else {
-            paths.appStorage = apiClientBowerPath + "/appstorage";
+            paths.appStorage = getAppStorage(apiClientBowerPath);
         }
 
         paths.syncDialog = "scripts/sync";
@@ -1503,9 +1393,6 @@ var AppInfo = {};
         define("cryptojs-sha1", [sha1Path]);
         define("cryptojs-md5", [md5Path]);
 
-        // Done
-        define("emby-icons", ['webcomponentsjs', "html!" + bowerPath + "/emby-icons/emby-icons.html"]);
-
         define("paper-button", ["html!" + bowerPath + "/paper-button/paper-button.html"]);
         define("paper-icon-button", ["html!" + bowerPath + "/paper-icon-button/paper-icon-button.html"]);
 
@@ -1630,6 +1517,9 @@ var AppInfo = {};
             return Emby.Page;
         });
 
+        define("headroom-window", ['headroom'], createWindowHeadroom);
+        define("hammer-main", ['hammer'], createMainContentHammer);
+
         // mock this for now. not used in this app
         define("playbackManager", [], function () {
             return {
@@ -1776,9 +1666,9 @@ var AppInfo = {};
 
     function onDialogOpen(dlg) {
         if (dlg.classList.contains('formDialog')) {
-            if (!dlg.classList.contains('background-theme-b')) {
-                dlg.classList.add('background-theme-a');
-                dlg.classList.add('ui-body-a');
+            if (!dlg.classList.contains('background-theme-a')) {
+                dlg.classList.add('background-theme-b');
+                dlg.classList.add('ui-body-b');
             }
         }
     }
@@ -2031,7 +1921,8 @@ var AppInfo = {};
             path: '/channels.html',
             dependencies: [],
             autoFocus: false,
-            transition: 'fade'
+            transition: 'fade',
+            controller: 'scripts/channels'
         });
 
         defineRoute({
@@ -2289,8 +2180,9 @@ var AppInfo = {};
 
         defineRoute({
             path: '/livetvseriestimer.html',
-            dependencies: [],
-            autoFocus: false
+            dependencies: ['emby-checkbox', 'emby-input', 'emby-button', 'emby-collapse', 'scripts/livetvcomponents', 'scripts/livetvseriestimer', 'livetvcss'],
+            autoFocus: false,
+            controller: 'scripts/livetvseriestimer'
         });
 
         defineRoute({
@@ -2435,7 +2327,7 @@ var AppInfo = {};
 
         defineRoute({
             path: '/mysync.html',
-            dependencies: ['scripts/syncactivity', 'scripts/taskbutton', 'emby-button'],
+            dependencies: [],
             autoFocus: false,
             transition: 'fade',
             controller: 'scripts/mysync'
@@ -2601,7 +2493,8 @@ var AppInfo = {};
         defineRoute({
             path: '/syncactivity.html',
             dependencies: [],
-            autoFocus: false
+            autoFocus: false,
+            controller: 'scripts/syncactivity'
         });
 
         defineRoute({
@@ -2866,7 +2759,11 @@ var AppInfo = {};
 
             if (!browserInfo.tv && !AppInfo.isNativeApp) {
                 if (navigator.serviceWorker) {
-                    navigator.serviceWorker.register('serviceworker.js');
+                    try {
+                        navigator.serviceWorker.register('serviceworker.js');
+                    } catch (err) {
+                        console.log('Error registering serviceWorker: ' + err);
+                    }
                 }
 
                 if (window.Notification) {
@@ -2995,4 +2892,5 @@ pageClassOn('viewshow', "page", function () {
     }
 
     Dashboard.ensureHeader(page);
-});
\ No newline at end of file
+});
+
